<?php

$LANG = array(

#header.php
'MENU'					=> 'меню',
'HOME'					=> 'Главная',
'GOTO_CONTENT'			=> 'Перейти к содержанию',
'GOTO_MENU'				=> 'Перейти к меню',
'COMMENTS_RSS_FEEDS'	=> 'RSS-каналы комментариев',
'COMMENTS'				=> 'Комментарии',
'ARTICLES_RSS_FEEDS'	=> 'Rss-каналы статей',
'ARTICLES'				=> 'Статьи',

# sidebar.php
'CATEGORIES' 			=> 'Категории',
'LATEST_ARTICLES'		=> 'Последние статьи',
'LATEST_COMMENTS'		=> 'Последние комментарии',
'ARCHIVES'				=> 'Архив',

# footer.php
'POWERED_BY'			=> 'Работает на',
'PLUXML_DESCRIPTION'	=> 'Блог и Cms без баз данных',
'IN'					=> 'в',
'ADMINISTRATION'		=> 'Администрация',
'GOTO_TOP'				=> 'Перейти в верх',
'TOP'					=> 'Вверх',

# erreur.php
'ERROR'					=> 'Обнаружена ошибка',
'BACKTO_HOME'			=> 'Перейти на главную',

# common
'WRITTEN_BY'			=> 'Автор',
'CLASSIFIED_IN'			=> 'Частные объявления на',
'TAGS'					=> 'Тэги',

# commentaires.php
'SAID'					=> 'сказал',
'WRITE_A_COMMENT'		=> 'Создать комментарий',
'NAME'					=> 'Имя',
'WEBSITE'				=> 'сайта (необязательно)',
'EMAIL'					=> 'E-mail (необязательно)',
'COMMENT'				=> 'Комментарий',
'CLEAR'					=> 'Очистить',
'SEND'					=> 'Отправить',
'COMMENTS_CLOSED'		=> 'Комментарии запрещенны',
'ANTISPAM_WARNING'		=> 'Анти-спам проверка',

'REPLY'					=> 'ответ',
'REPLY_TO'				=> 'ответ',
'CANCEL'				=> 'отменить',

);

?>